pub struct Board {
pub templates: Vec<(String, GrayImage)>,
pub bonus_templates: Vec<(String, GrayImage)>,
}Expand description
Wordfeud board recognizer
Fields
templates: Vec<(String, GrayImage)>bonus_templates: Vec<(String, GrayImage)>Implementations
Sourceimpl Board
impl Board
pub fn new() -> Board
Sourcepub fn recognize_screenshot(
&self,
screenshot: &GrayImage,
) -> Result<OcrResults, Error>
pub fn recognize_screenshot( &self, screenshot: &GrayImage, ) -> Result<OcrResults, Error>
Recognize a wordfeud board screenshot.
Returns a result that contains the detected tiles on the board and in the rack, and the detected board with the bonus tiles locations. The recognition process consists of these phases:
- Segmentation of the board: find the board and rack area, and locate the cells on the board and the rack
- Use template matching to recognize the tiles and bonus squares
Errors
- The screenshot can not be segmented properly
pub fn recognize_screenshot_from_file( &self, screenshot_filename: &str, ) -> Result<OcrResults, Error>
pub fn recognize_screenshot_from_memory( &self, screenshot: &[u8], ) -> Result<OcrResults, Error>